# wnix

Unix coreutils for software 2.0

## examples

```bash
cat usr/share/cats.jpg | input

cat usr/share/cats.jpg | input "How many cats are there?"

cat usr/share/cats.jpg | input "How many dogs are there?"
```
